@@ -2,8 +2,8 @@
 
 use std::{io, sync::Arc, time::Duration};
 
-use futures::{future, FutureExt};
-use shadowsocks::{config::Mode, ServerAddr};
+use futures::{FutureExt, future};
+use shadowsocks::{ServerAddr, config::Mode};
 
 use crate::{
     config::RedirType,
