@@ -73,17 +73,9 @@ impl UdpRedirSocket {
         socket.set_reuse_address(true)?;
         if reuse_port {
             if let Err(err) = socket.set_reuse_port(true) {
-                if let Some(errno) = err.raw_os_error() {
-                    match errno {
-                        libc::ENOPROTOOPT => {
-                            // SO_REUSEPORT is supported after 3.9
-                            trace!("failed to set SO_REUSEPORT, error: {}", err);
-                        }
-                        _ => {
-                            error!("failed to set SO_REUSEPORT, error: {}", err);
-                            return Err(err);
-                        }
-                    }
+                if let Some(libc::ENOPROTOOPT) = err.raw_os_error() {
+                    // SO_REUSEPORT is supported after 3.9
+                    trace!("failed to set SO_REUSEPORT, error: {}", err);
                 } else {
                     error!("failed to set SO_REUSEPORT, error: {}", err);
                     return Err(err);
